Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'source/blender/makesdna/DNA_object_types.h')
-rw-r--r--source/blender/makesdna/DNA_object_types.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/source/blender/makesdna/DNA_object_types.h b/source/blender/makesdna/DNA_object_types.h
index b142939eaeb..bfa7400f926 100644
--- a/source/blender/makesdna/DNA_object_types.h
+++ b/source/blender/makesdna/DNA_object_types.h
@@ -124,7 +124,7 @@ struct CustomData_MeshMasks;
typedef struct Object_Runtime {
/**
* The custom data layer mask that was last used
* to calculate mesh_eval and mesh_deform_eval.
*/
CustomData_MeshMasks last_data_mask;
@@ -141,25 +141,25 @@ typedef struct Object_Runtime {
char _pad1[3];
/**
* Denotes whether the evaluated mesh is owned by this object or is referenced and owned by
* somebody else.
*/
- char is_mesh_eval_owned;
+ char is_data_eval_owned;
/** Axis aligned boundbox (in localspace). */
struct BoundBox *bb;
/**
* Original mesh pointer, before object->data was changed to point
* to mesh_eval.
* Is assigned by dependency graph's copy-on-write evaluation.
*/
- struct Mesh *mesh_orig;
+ struct ID *data_orig;
/**
* Mesh structure created during object evaluation.
* It has all modifiers applied.
*/
- struct Mesh *mesh_eval;
+ struct ID *data_eval;
/**
* Mesh structure created during object evaluation.
* It has deformation only modifiers applied on it.
@@ -124,7 +124,7 @@ struct CustomData_MeshMasks;
/**
* The custom data layer mask that was last used
- * to calculate mesh_eval and mesh_deform_eval.
+ * to calculate data_eval and mesh_deform_eval.
*/
CustomData_MeshMasks last_data_mask;
@@ -141,25 +141,25 @@ typedef struct Object_Runtime {
char _pad1[3];
/**
- * Denotes whether the evaluated mesh is owned by this object or is referenced and owned by
+ * Denotes whether the evaluated data is owned by this object or is referenced and owned by
* somebody else.
*/
@@ -141,25 +141,25 @@ typedef struct Object_Runtime {
struct BoundBox *bb;
/**
- * Original mesh pointer, before object->data was changed to point
- * to mesh_eval.
+ * Original data pointer, before object->data was changed to point
+ * to data_eval.
* Is assigned by dependency graph's copy-on-write evaluation.
*/
@@ -141,25 +141,25 @@ typedef struct Object_Runtime {
/**
- * Mesh structure created during object evaluation.
+ * Object data structure created during object evaluation.
* It has all modifiers applied.
*/